//
//  AppDelegate.swift
//  BeforeSendCrash
//
//  Created by Lee Watkins on 04/11/2024.
//

import UIKit
import Sentry

@main
class AppDelegate: UIResponder, UIApplicationDelegate {
    func application(_ application: UIApplication, didFinishLaunchingWithOptions launchOptions: [UIApplication.LaunchOptionsKey: Any]?) -> Bool {
        SentrySDK.start { options in
            // Include a DSN for testing
            options.dsn = ""
            // It's unclear whether these settings are related,
            // but I've included them to match the sample project to our app
            // as closely as possible.
            options.enableSwizzling = false
            options.enableAppHangTracking = false

            // This is the inclusion that definitively causes the crash.
            // ie: if we remove the `beforeSend` block, we don't experience the crash.
            options.beforeSend = { event in
                // Our app has code inside the `beforeSend` closure, but we're tried the following to debug:
                // - wrap the contents of the closure in `DispatchQueue.main.sync`. Result: crash persists
                // - mark the closure as `@MainActor`. Result: crash persists
                // - remove all code except the `return event`. Result: crash persists
                // Conclusion: the mere presence of this block causes the crash, rather than the contents of it.
                return event
            }
        }
        return true
    }

    // MARK: UISceneSession Lifecycle

    func application(_ application: UIApplication, configurationForConnecting connectingSceneSession: UISceneSession, options: UIScene.ConnectionOptions) -> UISceneConfiguration {
        // Called when a new scene session is being created.
        // Use this method to select a configuration to create the new scene with.
        return UISceneConfiguration(name: "Default Configuration", sessionRole: connectingSceneSession.role)
    }

    func application(_ application: UIApplication, didDiscardSceneSessions sceneSessions: Set<UISceneSession>) {
        // Called when the user discards a scene session.
        // If any sessions were discarded while the application was not running, this will be called shortly after application:didFinishLaunchingWithOptions.
        // Use this method to release any resources that were specific to the discarded scenes, as they will not return.
    }


}

